@@ -22,6 +22,7 @@ along with the GNU MP Library.  If not, see http://www.gnu.org/licenses/.  */
 
 #if defined (__cplusplus)
 #include <iosfwd>   /* for std::istream, std::ostream, std::string */
+#include <cstdio>
 #endif
 
 
@@ -55,7 +56,7 @@ along with the GNU MP Library.  If not, see http://www.gnu.org/licenses/.  */
 
 /* Instantiated by configure. */
 #if ! defined (__GMP_WITHIN_CONFIGURE)
-#define _LONG_LONG_LIMB 1
+/* #undef _LONG_LONG_LIMB */
 #define __GMP_LIBGMP_DLL  0
 #endif
 
@@ -420,7 +421,7 @@ typedef __mpq_struct *mpq_ptr;
     GCC 4.3 and above with -std=c99 or -std=gnu99 implements ISO C99
     inline semantics, unless -fgnu89-inline is used.  */
 #ifdef __GNUC__
-#ifdef __GNUC_STDC_INLINE__
+#if (defined __GNUC_STDC_INLINE__) || (__GNUC__ == 4 && __GNUC_MINOR__ == 2)
 #define __GMP_EXTERN_INLINE extern __inline__ __attribute__ ((__gnu_inline__))
 #else
 #define __GMP_EXTERN_INLINE      extern __inline__
@@ -516,10 +517,8 @@ typedef __mpq_struct *mpq_ptr;
 
 #if defined (__cplusplus)
 extern "C" {
-#ifdef _GMP_H_HAVE_FILE
 using std::FILE;
 #endif
-#endif
 
 #define mp_set_memory_functions __gmp_set_memory_functions
 __GMP_DECLSPEC void mp_set_memory_functions __GMP_PROTO ((void *(*) (size_t),
@@ -2171,10 +2170,14 @@ enum
   GMP_ERROR_INVALID_ARGUMENT = 8
 };
 
+/* Define CC and CFLAGS which were used to build this version of GMP */
+#define __GMP_CC "cc"
+#define __GMP_CFLAGS "-O2 -pipe"
+
 /* Major version number is the value of __GNU_MP__ too, above and in mp.h. */
 #define __GNU_MP_VERSION 4
 #define __GNU_MP_VERSION_MINOR 2
-#define __GNU_MP_VERSION_PATCHLEVEL 2
+#define __GNU_MP_VERSION_PATCHLEVEL 4
 
 #define __GMP_H__
 #endif /* __GMP_H__ */
